@@ -100,12 +100,12 @@ class Oracle:
 
           mzd = self.__hic.getMatrixZoomData(chr, chr, "observed", 'SCALE' , "BP", reso)
           for index, row in sublist.iterrows():   
-            x1,x2,y1,y2 = self.makeRegion((row[CHROM_KEY],row[X1_KEY],row[X2_KEY],row[Y1_KEY],row[Y2_KEY]),self.__width-1,reso)
+            x1,x2,y1,y2 = make_region((row[CHROM_KEY],row[X1_KEY],row[X2_KEY],row[Y1_KEY],row[Y2_KEY]),self.__width-1,reso)
             mat = mzd.getRecordsAsMatrix(x1,x2,y1,y2)
 
             batch[index,:self.__width-1,:self.__width-1,0] = self.preprocess(mat)
           prediction = self.__model.predict(batch)
-          sublist['prediction'] = prediction
+          sublist['prediction'] = prediction.reshape(prediction.shape[0],)
           passed.append(sublist[sublist['prediction'] >= 0.5])
           failed = sublist[sublist['prediction'] < 0.5]
 
@@ -130,8 +130,12 @@ if __name__ == "__main__":
     MODEL_DIR = sys.argv[2]
     BEDPE_DIR = sys.argv[3]
     NORMALIZATION_TYPE = sys.argv[4]
+    if len(sys.argv)<6:
+      CHR_LIST = ['All']
+    else:
+      CHR_LIST = sys.argv[5].split(',')
 
-    oracle = Oracle(BEDPE_DIR, FILEPATH, MODEL_DIR, NORMALIZATION_TYPE)
+    oracle = Oracle(BEDPE_DIR, FILEPATH, MODEL_DIR, NORMALIZATION_TYPE, chr_list=CHR_LIST)
     passing, failing = oracle.run()
 
     print('Saving results to disk...')
